/* PUSH UP COUNTER


An ultrasonic sensor measures the distance between you and your head, if the distance is larger than 20 cm a rgb-led will shine red,
if the distance is between 10 and 20 cm, it turns magenta
and if it is less than 10 cm it turns blue, and a point appears on a lcd screen.
Every ten pushups it makes a sound.
You can reset the score with the push of a button.
 */
 
#include <LiquidCrystal.h> // LCD library

// set pins for rgb 
#define GREEN 11
#define RED 12
#define BLUE 10

//set pins for the ultrasonic sensor, button and buzzer
const int trigPin = 8; 
const int echoPin = 9;
const int buttonPin = A0;
const int b = 13;

long duration;
long distance;
int i;
int buttonState = 0;

// set lcd pins
LiquidCrystal lcd(7, 6, 5, 4, 3, 2); 

void setup() {
  // 9600 baud
  Serial.begin(9600);  

  //set pin modes
  pinMode(trigPin, OUTPUT); 
  pinMode(echoPin, INPUT);
  pinMode(buttonPin, INPUT);
  pinMode(b, OUTPUT);
  pinMode(GREEN, OUTPUT);
  pinMode(BLUE, OUTPUT);
  pinMode(RED, OUTPUT);

  //lcd setup
  lcd.begin(16, 2); 
  lcd.print("Push Ups:");

}

void loop() {

  // send out an ultra sonic sound for 10 microseconds and measure the time it took for the sound to go from the trigpin to the echo pin
  digitalWrite(trigPin, HIGH);
  delayMicroseconds(10);
  digitalWrite(trigPin, LOW);
  duration = pulseIn(echoPin, HIGH);
  //convert the time the signal took to travel to distance in cm
  distance = duration * 0.034/2; 

  //if the distance is 20+ cm the rgb is red
  if (distance >= 20) {
    setColor(255, 0, 0);
    delay(500);
  }

  //if the distance is 10 cm or lower the rgb is blue
  if (distance <= 10 ) {
    setColor(0, 255, 0);
    delay(500);
  }

  //if the distance is in beetwen 10 and 20 cm the rgb is green
  if (distance <= 20 && distance > 10) {
    setColor(0, 0, 255);
    delay(500);
  }
  
  //plays a sound every ten pushups
  if (i % 10 == 0 && i > 0) { 
                 tone(b, 450);
                 delay(50);
                 noTone(b);
                 delay(100);
                 tone(b, 450);
                 delay(50);
                 noTone(b);
                 delay(50);
                 tone(b, 450);
                 delay(100);
                 noTone(b);
                 
  }else{
    delay(350);
  }
  
  //if button is pressed reset the count
  buttonState = digitalRead(buttonPin); 
  if (buttonState == HIGH) {
    i = 0;
    lcd.setCursor(0,1);
    lcd.print("0      ");
  } 

  // set cursor on the second row
  lcd.setCursor(0, 1); 

  //print a point if a pushup has been done
  if (distance <= 10 ) {
    i++;
  } 
  
  lcd.print(i,DEC);                 

  //if the distance stays smaller then ten for a while, there are not aditional points given    
  while (distance <= 10) { 
      digitalWrite(trigPin, HIGH);
      delayMicroseconds(10);
      digitalWrite(trigPin, LOW);
      duration = pulseIn(echoPin, HIGH);
      distance = duration * 0.034/2;
      delay(100);
  }
}

void setColor(int red_V, int blue_V, int green_V){
  analogWrite(RED, red_V);
  analogWrite(GREEN, green_V);
  analogWrite(BLUE, blue_V);
}
